Struct Window
pub struct Window(/* private fields */);Available on crate feature
wayland and Linux only.Implementations
impl Window
impl Window
pub fn from_xdg_toplevel(toplevel: &XdgToplevel) -> Option<Window>
pub fn from_xdg_surface(surface: &XdgSurface) -> Option<Window>
pub fn from_toplevel_decoration( decoration: &ZxdgToplevelDecorationV1, ) -> Option<Window>
pub fn set_title(&self, title: impl Into<String>)
pub fn set_app_id(&self, app_id: impl Into<String>)
pub fn set_parent(&self, parent: Option<&Window>)
pub fn set_maximized(&self)
pub fn unset_maximized(&self)
pub fn set_minimized(&self)
pub fn set_fullscreen(&self, output: Option<&WlOutput>)
pub fn unset_fullscreen(&self)
pub fn request_decoration_mode(&self, mode: Option<DecorationMode>)
pub fn request_decoration_mode(&self, mode: Option<DecorationMode>)
Requests the window should use the specified decoration mode.
A mode of None indicates that the window does not care what type of decorations are used.
The compositor will respond with a configure. The configure will
indicate whether the window’s decoration mode has changed.
Configure loops
You should avoid sending multiple decoration mode requests to ensure you do not enter a configure loop.
pub fn move_(&self, seat: &WlSeat, serial: u32)
pub fn resize(&self, seat: &WlSeat, serial: u32, edges: ResizeEdge)
pub fn set_min_size(&self, min_size: Option<(u32, u32)>)
pub fn set_max_size(&self, max_size: Option<(u32, u32)>)
pub fn set_max_size(&self, max_size: Option<(u32, u32)>)
Protocol errors
The maximum size of the window may not be smaller than the minimum size.
pub fn xdg_toplevel(&self) -> &XdgToplevel
pub fn xdg_toplevel(&self) -> &XdgToplevel
Returns the underlying xdg toplevel wrapped by this window.